Module content_type

Module content_type 

Content-Type extraction.

This module parses the representation media type described by RFC 9110, Section 8.3. It does not inspect a message body or infer a media type when the field is absent.

Functions

extract_header_content_type
Extract and parse a singular Content-Type field as a media type.
extract_request_content_type
Extract and parse Content-Type from a complete request.