Content-Type extraction.
This module parses the representation media type described by RFC 9110, Section 8.3. It does not inspect a message body or infer a media type when the field is absent.
Functions
- extract_
header_ content_ type - Extract and parse a singular
Content-Typefield as a media type. - extract_
request_ content_ type - Extract and parse
Content-Typefrom a complete request.